@@ -5,10 +5,10 @@
 """
 from .cnn import *
 from .lstm import *
-from .span_extractor import *
+# from .span_extractor import *
 __all__ = [
     "CNN",
     "LSTM",
-    "EndpointSpanExtractor",
-    "SelfAttentiveSpanExtractor",
+    # "EndpointSpanExtractor",
+    # "SelfAttentiveSpanExtractor",
 ]
